@@ -1,7 +1,10 @@
 from sagemaker import Session
 from sagemaker.transformer import Transformer
 from sbdscommons.constants import BUCKET
+from sbdscommons.constants import PARAMS_FOLDER
 from sbdscommons.utils.yaml_utils import load_from_yaml
+from sbdscommons.constants import MODEL_INPUT_DATA_TEMPLATE_QUERY
+from sbdscommons.constants import PREDICT_INPUT_DATA_TEMPLATE_QUERY
 
 from .base import Model
 from .base import PrepInput
@@ -15,6 +18,8 @@ class SbModel:
                  model: Model,
                  input_prep: PrepInput,
                  model_version: str,
+                 query_dict: dict,
+                 options_dict: dict,
                  bucket: str = BUCKET
                  ):
         self.model = model
@@ -26,6 +31,9 @@ class SbModel:
         self.output_path = f'{model_name}/output_data'
         self.model_path = f'{model_name}/model'
         self.bucket = bucket
+        self.params_path = f'{PARAMS_FOLDER}/{model_name}.yaml'
+        self.query_dict = query_dict
+        self.options_dict = options_dict
 
     def __repr__(self):
         return self.model_id
@@ -44,11 +52,10 @@ class SbModel:
         transformed_input = self.input_prep.transform(predict_input)
         return self.model.predict(transformed_input)
 
-    def unload_for_predict(self):
-        pass
-
-    def unload_for_predit(self):
-        pass
+    def unload_model_data_to_s3(self):
+        model_input_data_query = MODEL_INPUT_DATA_TEMPLATE_QUERY.format(MODEL_NAME=self.model_name).format(**self.query_dict)
+        predict_input_data_query = PREDICT_INPUT_DATA_TEMPLATE_QUERY.format(MODEL_NAME=self.model_name).format(**self.query_dict)
+        return model_input_data_query, predict_input_data_query
 
     def batch_transform_job(self):
         # CREATE A batch prediction job
